% dgr = calc_gab(sig,N,Q,T)
% 
% calc_gab calculates the Gabor decomposition of a signal x
% using n time windows and length(x)/(Q*N) frequency windows.
% The window used is a Gaussian of time-spread T
%
% sig : the signal
% N : number of Gabor coefficients in time
% Q : the redundancy of the Gabor decomposition
% T : the time-spread of the Gaussian window. 
%     (so that w(-T/2) and w(T/2) = 0.005*w(0))
function dgr = calc_gab(sig,N,Q,T)

if nargin<4
  error('Too few arguments in Gabor decomposition');
end;

sig = sig(:).';
N1 = length(sig);
if N1<3
  error('Signal is too short');
end;

% The Gaussian window of time-spread T
h = exp(log(0.005) * linspace(-1,1,T)'.^2 );
h = h'/norm(h);
Nh= T;

M=Q*N1/N;       % No. of frequency windows
Mb=N1/N;        % frequency-shift between two Gabor coefficients
Nb=N1/M;        % time-shift between two Gabor coefficients

% Time shift to be correctly localized in time :
alpha=round((2*N1/N-1-Nh)/(2*Q));
hN1=zeros(N1,1); 
hN1(round((N1-(Nh-1))/2)-alpha:round((N1+Nh-1)/2)-alpha)=h;	

%keyboard;
DZTh=zeros(M,Nb);
Msig=reshape(hN1,Nb,M);
DZTh=fft(Msig.')/sqrt(M);

Mzh=zeros(M,Nb);
x=(1:M);

for l=0:Q-1,
 md=modulo(x-l*M/Q,M);
 Mzh=Mzh+abs(DZTh(md,:)).^2;
end

[ind1,ind2]=find(Mzh<eps);
for l=1:length(ind1),
 Mzh(ind1(l),ind2(l))=1;
end
 
% Zak transform of the biorthogonal (dual frame) window gam
DZTgam=zeros(M,Nb);
DZTgam=DZTh./Mzh;
gam=real(izak(DZTgam))/N1;

% Computation of the Gabor coefficients from the dual frame window
dgr=zeros(M,N);

index = repmat((1:N1)',1,N)-repmat(M/Q*(1:N),N1,1);
index = index+(index<=0)*N1;
gm = gam(index);
p = ceil(N1/2);
% fftshift 
gm = [gm(p+1:N1,:);gm(1:p,:)];
% fft
dgrN1 = fft(repmat(sig(:),1,N).*gm);
dgr=dgrN1(1:Nb:N1,:);
dgr = dgr(1:M/2,:);



