% A = gen_Q4(M,n1,T,d)
%
% This function generates the set of vectors necessary for the
% hybrid estimation of instantaneous frequency (see hybifest.m)
% assuming an over-sampling of 4 in the Gabor decomposition
%
% M is the number of time windows
% n1 is the length of the signal
% T is the time spread of the signal
% d is the Manhattan distance of the points to include
function A = gen_Q4(M,n1,T,d)

A = cell(d+1,d+1);
sigmasq = -0.5*((T-1)/2)^2/log(0.005);

N = (4*n1)/M;
Mb=n1/M;        % time-shift between two Gabor coefficients
L = T-1;
tt = (-L+1):L;

for ii = 1:d+1
  %time
  for jj = 1:d+1
    %frequency
    A{ii,jj} = zeros(8,2*L);
    for kk = 1:8
      %phase shift      
      A{ii,jj}(kk,:) = exp(-(tt-Mb).^2/sigmasq)*exp(-((ii-1)*Mb/2)^2/sigmasq).*exp(j*pi*(jj-1)/N.*(tt));
      if (ii==1&jj==1&kk==1)
	nm = norm(A{1,1}(1,:));
      end;	
      A{ii,jj}(kk,:) = A{ii,jj}(kk,:)/nm;
      A{ii,jj}(kk,:) = A{ii,jj}(kk,:)*exp(j*pi*(kk-1)/4);
    end;
  end;
end;

save(strcat('A4',num2str(n1),'_',num2str(M),'_',num2str(d)),'A');




