% A script demonstrating the application of the hybrid IF
% estimation technique to a seismic signal.
% Comparison is made between the hybrid IF estimate, the
% spectrogram-based estimate and the AOK-based estimate (see
% www.dsp.rice.edu/~richb for a discussion of the AOK)
%

% Load the signal and make it analytic
load al100.dat
al100 = hilbert(al100);

d = 2;
% Calculate the stored signal matrix
A = gen_Q4(64,512,65,d);
%
[hybiflaw,c] = hybifest(al100,64,65,d,A);

%[hybiband,c] = hybibandest(al100,64,65,d,A);

% Calculate spectrogram estimate
[tfr,tt,ff] = tfrsp(al100,[1:512],128,hamming(63));
[fm,b2] = momttfr(tfr,'tfrsp');

% Draw figures, loading the AOK time-frequency representation and
% the associated IF estimate
figure;
subplot(211)
l = line([1:512],hybiflaw);
set(l,'Color','k');
set(l,'LineWidth',2);
hold on;
l = line([1:512],fm);
set(l,'Color','g');
set(l,'LineWidth',2);
h = gca;
set(h,'XLim',[1,512]);
set(h,'YLim',[0,0.25]);
hold on;
load aok_seis
[fm2,b2] = momttfr(aok_seis,'tfrwv');
l = line([1:512],fm2);
set(l,'Color','r');
set(l,'LineWidth',2);
subplot(212)
imagesc(flipud(aok_seis(1:19,:)));
h = gca;
set(h,'YTick',[4,12,20]);
set(h,'YTickLabel',[0.25,0.125,0]);


